@@ -407,7 +407,7 @@ class MyCli:
         socket: str | None = "",
         charset: str | None = "",
         local_infile: bool = False,
-        ssl: dict[str, Any] | None = {},
+        ssl: dict[str, Any] | None = None,
         ssh_user: str | None = "",
         ssh_host: str | None = "",
         ssh_port: int = 22,
@@ -802,7 +802,8 @@ class MyCli:
                             click.echo("LLM Response:")
                             click.echo(context)
                             click.echo("---")
-                        click.echo(f"Time: {duration:.2f} seconds")
+                        if special.is_timing_enabled():
+                            click.echo(f"Time: {duration:.2f} seconds")
                         text = self.prompt_app.prompt(default=sql or '')
                     except KeyboardInterrupt:
                         return
@@ -887,7 +888,7 @@ class MyCli:
                     # Restart connection to the database
                     sqlexecute.connect()
                     try:
-                        for title, cur, headers, status in sqlexecute.run(f"kill {connection_id_to_kill}"):
+                        for _title, _cur, _headers, status in sqlexecute.run(f"kill {connection_id_to_kill}"):
                             status_str = str(status).lower()
                             if status_str.find("ok") > -1:
                                 logger.debug("cancelled query, connection id: %r, sql: %r", connection_id_to_kill, text)
