@@ -1,6 +1,8 @@
+# type: ignore
+
 from mycli.packages.completion_engine import suggest_type
-from .test_completion_engine import sorted_dicts
 from mycli.packages.special.utils import format_uptime
+from test.test_completion_engine import sorted_dicts
 
 
 def test_u_suggests_databases():
