@@ -1,3 +1,5 @@
+# type: ignore
+
 from collections import namedtuple
 import os
 import shutil
@@ -320,7 +322,8 @@ def test_dsn(monkeypatch):
         def __init__(self, **args):
             self.logger = Logger()
             self.destructive_warning = False
-            self.formatter = Formatter()
+            self.main_formatter = Formatter()
+            self.redirect_formatter = Formatter()
 
         def connect(self, **args):
             MockMyCli.connect_args = args
@@ -483,7 +486,8 @@ def test_ssh_config(monkeypatch):
         def __init__(self, **args):
             self.logger = Logger()
             self.destructive_warning = False
-            self.formatter = Formatter()
+            self.main_formatter = Formatter()
+            self.redirect_formatter = Formatter()
 
         def connect(self, **args):
             MockMyCli.connect_args = args
